#include <iostream>
#ifndef _GLIBCXX_NO_ASSERT
#include <cassert>
#endif
#include <cctype>
#include <cerrno>
#include <cfloat>
#include <ciso646>
#include <climits>
#include <clocale>
#include <cmath>
#include <csetjmp>
#include <csignal>
#include <cstdarg>
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <ctime>

#if __cplusplus >= 201103L
#include <ccomplex>
#include <cfenv>
#include <cinttypes>
#include <cstdbool>
#include <cstdint>
#include <ctgmath>
#include <cwchar>
#include <cwctype>
#endif

// C++
#include <algorithm>
#include <bitset>
#include <complex>
#include <deque>
#include <exception>
#include <fstream>
#include <functional>
#include <iomanip>
#include <ios>
#include <iosfwd>
#include <iostream>
#include <istream>
#include <iterator>
#include <limits>
#include <list>
#include <locale>
#include <map>
#include <memory>
#include <new>
#include <numeric>
#include <ostream>
#include <queue>
#include <set>
#include <sstream>
#include <stack>
#include <stdexcept>
#include <streambuf>
#include <string>
#include <typeinfo>
#include <utility>
#include <valarray>
#include <vector>

#if __cplusplus >= 201103L
#include <array>
#include <atomic>
#include <chrono>
#include <condition_variable>
#include <forward_list>
#include <future>
#include <initializer_list>
#include <mutex>
#include <random>
#include <ratio>
#include <regex>
#include <scoped_allocator>
#include <system_error>
#include <thread>
#include <tuple>
#include <typeindex>
#include <type_traits>
#include <unordered_map>
#include <unordered_set>
#endif

#define rep(i,a,b) for(int i = a; i <(b);++i)
#define repR(i,a,b) for(int i = a-1; i >= b;--i)
#define sz(x) (int)(x).size()
#define pb push_back
#define F first
#define S second
#define all(x) begin(x), end(x)

using ll = long long;


using namespace std;

typedef pair<ll, ll> pii;
typedef vector<ll> vi;

struct SparseTable {
    vector<vector<ll>> table; // Store indices
    vector<ll> logValues;
    const vector<ll>& arr;
    int n;
    SparseTable(const vector<ll>& inputArr) : arr(inputArr) {
        n = arr.size();
        int maxLog = log2(n) + 1;
        table.assign(n, vector<ll>(maxLog));

        logValues.resize(n + 1);
        logValues[1] = 0;
        for (int i = 2; i <= n; ++i) {
            logValues[i] = logValues[i / 2] + 1;
        }

        for (int i = 0; i < n; ++i) {
            table[i][0] = i;
        }

        for (int j = 1; j < maxLog; ++j) {
            for (int i = 0; i + (1 << j) <= n; ++i) {
                int leftIndex = table[i][j - 1];
                int rightIndex = table[i + (1 << (j - 1))][j - 1];
                table[i][j] = (arr[leftIndex] >= arr[rightIndex]) ? leftIndex : rightIndex;
            }
        }
    }

    int query(int l, int r) {
        int logLen = logValues[r - l + 1];
        int leftIndex = table[l][logLen];
        int rightIndex = table[r - (1 << logLen) + 1][logLen];
        return (arr[leftIndex] >= arr[rightIndex]) ? leftIndex : rightIndex;
    }
};

struct FT {
    vector<ll> s;
    FT(int n) : s(n) {}
    void update(int pos, ll dif) { // a[pos] += dif
        for (; pos < sz(s); pos |= pos + 1) s[pos] += dif;
    }
    ll query(int pos) { // sum of values in [0, pos)
        ll res = 0;
        for (; pos > 0; pos &= pos - 1) res += s[pos-1];
        return res;
    }
    int lower_bound(ll sum) {// min pos st sum of [0, pos] >= sum
        // Returns n if no sum is >= sum, or -1 if empty sum is.
        if (sum <= 0) return -1;
        int pos = 0;
        for (int pw = 1 << 25; pw; pw >>= 1) {
            if (pos + pw <= sz(s) && s[pos + pw-1] < sum)
                pos += pw, sum -= s[pos-1];
        }
        return pos;
    }
};


ll countVals = 0;
ll k;
ll inf = 1e15;
// query is {value, {{L,R}, dir}} where L and R are inclusive
vector<pair<ll,pair<ll,pii>>> ft_queries;
void dnc(vi& pref, vi& arr, SparseTable& st) {
    stack<pair<ll,ll>> qu;
    qu.push({1,pref.size()-1});
    int cnt = 0;
    while (!qu.empty()) {
        auto [l, r] = qu.top();
        qu.pop();
        if (l > r) continue;
        ll swapped = st.query(l,r);
        ll diffval = 0;
        if (arr[swapped] > 0) {
            diffval = (k+1)*arr[swapped];
        }
        if (r-swapped < swapped-l) {
            // I want to find how many end with i as its right element
            rep(i,swapped,r+1) {
                // <= pref[i]-diffval ---- >= pref[i]-diffval+1
                ft_queries.push_back({pref[i]-diffval+1,{-1,{l-1,swapped-1}}});
            }
        }else {
            rep(i,l,swapped+1) {
                ft_queries.push_back({pref[i-1]+diffval,{1,{swapped,r}}});
            }
        }
        qu.push({l,swapped-1});
        qu.push({swapped+1,r});
    }
}

void solve() {
    int n; cin>>n>>k;
    vi h(n+1,0);
    vi a(n+1,0);
    vi arr(n+1,0);
    rep(i,1,n+1) {
        cin>>h[i];
    }
    rep(i,1,n+1) {
        cin>>a[i];
    }
    rep(i,1,n+1) {
        arr[i] = h[i]-a[i];
        if (arr[i] < 0) {
            arr[i] *= k;
        }
    }
    arr[0] = 0;
    vi pref(n+1);
    ll minv = 0; ll maxv = 0;
    rep(i,1,n+1) {
        pref[i] = pref[i-1]+arr[i];
        minv = min(minv,pref[i]);
        maxv = max(maxv,pref[i]);
    }
    SparseTable st(arr);
    FT tree(n+1);
    dnc(pref,arr,st);
    rep(i,0,n+1) {
        ft_queries.push_back({pref[i],{100,{i,i}}});
    }
    sort(ft_queries.begin(),ft_queries.end());
    reverse(ft_queries.begin(),ft_queries.end());
    rep(i,0,ft_queries.size()) {
        ll v = ft_queries[i].F;
        ll q = ft_queries[i].S.F;
        ll l = ft_queries[i].S.S.F;
        ll r = ft_queries[i].S.S.S;
        if (q == 100) {
            tree.update(l,1);
        }else {
            ll ft_q = tree.query(r+1)-tree.query(l);
            if (q == 1) {
                countVals += ft_q;
            }else {
                countVals += r-l+1-ft_q;
            }
        }

    }
    cout<<countVals<<endl;

}

int main() {
    ios::sync_with_stdio(0);
    cin.tie(0);
    int t = 1;
    while(t--)
        solve();

    return 0;
}
